@@ -1,4 +1,4 @@
-fillFrame <- function(f,x,cond) {
+fillFrame <- function(f, x, cond) {
   ## x  = data frame of x variable(s) being changed
   ## x2 = variables being filled by median
   ## x3 = variables specified by cond
@@ -13,11 +13,14 @@ fillFrame <- function(f,x,cond) {
   x2 <- lapply(as.data.frame(f[,setdiff(names(f), exclude)]), median)
   names(x2) <- setdiff(names(f), exclude)
   x3 <- cond
+  for (j in seq_along(x3)) {
+    if (is.character(x3[[j]])) x3[[j]] <- factor(x3[[j]], levels=levels(f[,names(x3)[j]]))
+  }
   
   if (length(x2)>0 & length(x3)>0) newdf <- data.frame(x,x2,x3,check.names=FALSE)
   else if (length(x2)>0 & length(x3)==0) newdf <- data.frame(x,x2,check.names=FALSE)
   else if (length(x2)==0 & length(x3)>0) newdf <- data.frame(x,x3,check.names=FALSE)
   else newdf <- x
   
-  return(newdf)
+  newdf
 }
