@@ -1,10 +1,10 @@
 getXY <- function(fit, f, name, nn, cond, type, trans, xtrans, alpha, jitter, ...) {
   if (type=="conditional") {
     x <- setupD(fit, f, name, nn, cond, ...)
-    y <- Response(fit, x, trans, alpha)
+    y <- Response(fit, x, trans, alpha, ...)
   } else if (type=="contrast") {
     x <- setupX(fit, f, name, nn, cond, ...)
-    y <- Terms(fit, f, x, trans, alpha)
+    y <- Terms(fit, f, x, trans, alpha, ...)
   }
   
   if (jitter) x$x <- jitter(x$x)
