@@ -7,7 +7,7 @@ ovarian$rx <- factor(ovarian$rx)
 ## Basic
 fit <- coxph(Surv(futime,fustat)~age+rx,data=ovarian)
 visreg(fit,"age")
-visreg(fit,"age", type="effect")
+visreg(fit,"age", type="contrast")
 visreg(fit,"rx")
 visreg(fit, "age", trans=exp)
 visreg(fit,"age",trans=exp,ylim=c(0,20))
@@ -25,5 +25,5 @@ fit <- coxph(Surv(futime,fustat)~ns(age,4)+rx,data=ovarian)
 par(mfrow=c(1,1))
 visreg(fit, "age")
 visreg(fit, "rx")
-visreg(fit, "age", type="effect")
-visreg(fit, "rx", type="effect")
+visreg(fit, "age", type="contrast")
+visreg(fit, "rx", type="contrast")
